durtools.multiply_duration_pair_and_try_to_preserve_numerator
=============================================================

.. autofunction:: abjad.tools.durtools.multiply_duration_pair_and_try_to_preserve_numerator
